@@ -779,6 +779,15 @@ class PlainMzMLWriter(ComponentDispatcher, XMLDocumentWriter):
         else:
             _encoding = encoding
         dtype = encoding_map[_encoding]
+        if dtype is None:
+            if len(array):
+                val = array[0]
+                dtype = encoding_map[val.__class__]
+            else:
+                try:
+                    dtype = array.dtype
+                except AttributeError:
+                    dtype = np.float32
         array = np.array(array, dtype=dtype)
         encoded_binary = encode_array(
             array, compression=compression, dtype=dtype)
@@ -789,20 +798,13 @@ class PlainMzMLWriter(ComponentDispatcher, XMLDocumentWriter):
             override_length = False
         params = []
         if array_type is not None:
+            params.append(array_type)
             if isinstance(array_type, Mapping):
                 array_type_ = array_type['name']
             else:
                 array_type_ = array_type
-            params.append(array_type)
             if array_type_ not in ARRAY_TYPES:
-                term = {'name': NON_STANDARD_ARRAY, 'value': array_type_}
-                if isinstance(array_type, Mapping):
-                    for key, value in array_type.items():
-                        if key != 'name':
-                            term[key] = value
-                params.append(term)
-            else:
-                pass
+                params.append(NON_STANDARD_ARRAY)
         params.append(compression_map[compression])
         params.append(dtype_to_encoding[dtype])
         encoded_length = len(encoded_binary)
